import { NodeValueType } from './NodeValueType';
import { NodeGraph } from './NodeGraph';
import { IParticle } from '../Particle';
import { Vector2, Vector3, Vector4 } from 'three';
import { NodeData } from './Node';
export interface ExecutionContext {
    inputs?: NodeValue[];
    outputs?: NodeValue[];
    particle?: IParticle;
    [key: string]: any;
}
type NodeValue = number | boolean | Vector2 | Vector3 | Vector4 | Array<any>;
type NodeExecFunction = (context: ExecutionContext, data: NodeData, inputs: NodeValue[], outputs: NodeValue[]) => void;
export interface NodeTypeSignature {
    inputTypes: NodeValueType[];
    outputTypes: NodeValueType[];
    func: NodeExecFunction;
}
export declare enum NodeType {
    Variable = 0,
    Expression = 1,
    Storage = 2,
    Function = 3
}
export declare class NodeDef {
    name: string;
    type: NodeType;
    nodeTypeSignatures: NodeTypeSignature[];
    constructor(name: string, type: NodeType);
    addSignature(inputTypes: NodeValueType[], outputTypes: NodeValueType[], func: NodeExecFunction): void;
}
export declare class GraphNodeType extends NodeDef {
    nodeGraph: NodeGraph;
    constructor(nodeGraph: NodeGraph);
}
export {};
