import { Particle } from '../Particle';
import { Constructable, ParameterPair } from '../TypeUtil';
import { JsonMetaData } from '../ParticleSystem';
export interface ShapeJSON {
    type: string;
    radius?: number;
    arc?: number;
    thickness?: number;
    donutRadius?: number;
    angle?: number;
    width?: number;
    height?: number;
    column?: number;
    row?: number;
    mesh?: string;
    particleSystem?: string;
}
export interface EmitterShape {
    type: string;
    initialize(particle: Particle): void;
    toJSON(): ShapeJSON;
    clone(): EmitterShape;
}
export interface EmitterShapePlugin {
    type: string;
    constructor: Constructable<EmitterShape>;
    params: ParameterPair[];
    loadJSON: (json: any, meta: JsonMetaData) => EmitterShape;
}
export declare const EmitterShapes: {
    [key: string]: EmitterShapePlugin;
};
export declare function EmitterFromJSON(json: ShapeJSON, meta: JsonMetaData): EmitterShape;
